from . import hrpc_pb2 as hrpc__pb2
import purerpc

from . import schema_pb2 as schema__pb2


class HyperspaceServicer(purerpc.Servicer):
    async def Status(self, input_message):
        raise NotImplementedError()

    @property
    def service(self) -> purerpc.Service:
        service_obj = purerpc.Service("hyperspace.Hyperspace")
        service_obj.add_method(
            "Status",
            self.Status,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                hrpc__pb2.Void,
                schema__pb2.HyperspaceStatusResponse,
            ),
        )
        return service_obj


class HyperspaceStub:
    def __init__(self, channel):
        self._client = purerpc.Client("hyperspace.Hyperspace", channel)
        self.Status = self._client.get_method_stub(
            "Status",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                hrpc__pb2.Void,
                schema__pb2.HyperspaceStatusResponse,
            ),
        )


class CorestoreServicer(purerpc.Servicer):
    async def Open(self, input_message):
        raise NotImplementedError()

    async def OnFeed(self, input_message):
        raise NotImplementedError()

    @property
    def service(self) -> purerpc.Service:
        service_obj = purerpc.Service("hyperspace.Corestore")
        service_obj.add_method(
            "Open",
            self.Open,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.OpenRequest,
                schema__pb2.OpenResponse,
            ),
        )
        service_obj.add_method(
            "OnFeed",
            self.OnFeed,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.FeedEvent,
                hrpc__pb2.Void,
            ),
        )
        return service_obj


class CorestoreStub:
    def __init__(self, channel):
        self._client = purerpc.Client("hyperspace.Corestore", channel)
        self.Open = self._client.get_method_stub(
            "Open",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.OpenRequest,
                schema__pb2.OpenResponse,
            ),
        )
        self.OnFeed = self._client.get_method_stub(
            "OnFeed",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.FeedEvent,
                hrpc__pb2.Void,
            ),
        )


class HypercoreServicer(purerpc.Servicer):
    async def Get(self, input_message):
        raise NotImplementedError()

    async def Append(self, input_message):
        raise NotImplementedError()

    async def Update(self, input_message):
        raise NotImplementedError()

    async def Seek(self, input_message):
        raise NotImplementedError()

    async def Has(self, input_message):
        raise NotImplementedError()

    async def Cancel(self, input_message):
        raise NotImplementedError()

    async def Download(self, input_message):
        raise NotImplementedError()

    async def Downloaded(self, input_message):
        raise NotImplementedError()

    async def Undownload(self, input_message):
        raise NotImplementedError()

    async def Close(self, input_message):
        raise NotImplementedError()

    async def RegisterExtension(self, input_message):
        raise NotImplementedError()

    async def UnregisterExtension(self, input_message):
        raise NotImplementedError()

    async def SendExtension(self, input_message):
        raise NotImplementedError()

    async def AcquireLock(self, input_message):
        raise NotImplementedError()

    async def ReleaseLock(self, input_message):
        raise NotImplementedError()

    async def OnAppend(self, input_message):
        raise NotImplementedError()

    async def OnClose(self, input_message):
        raise NotImplementedError()

    async def OnPeerOpen(self, input_message):
        raise NotImplementedError()

    async def OnPeerRemove(self, input_message):
        raise NotImplementedError()

    async def OnExtension(self, input_message):
        raise NotImplementedError()

    async def OnWait(self, input_message):
        raise NotImplementedError()

    @property
    def service(self) -> purerpc.Service:
        service_obj = purerpc.Service("hyperspace.Hypercore")
        service_obj.add_method(
            "Get",
            self.Get,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.GetRequest,
                schema__pb2.GetResponse,
            ),
        )
        service_obj.add_method(
            "Append",
            self.Append,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.AppendRequest,
                schema__pb2.AppendResponse,
            ),
        )
        service_obj.add_method(
            "Update",
            self.Update,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.UpdateRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "Seek",
            self.Seek,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.SeekRequest,
                schema__pb2.SeekResponse,
            ),
        )
        service_obj.add_method(
            "Has",
            self.Has,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.HasRequest,
                schema__pb2.HasResponse,
            ),
        )
        service_obj.add_method(
            "Cancel",
            self.Cancel,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.CancelRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "Download",
            self.Download,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.DownloadRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "Downloaded",
            self.Downloaded,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.DownloadedRequest,
                schema__pb2.DownloadedResponse,
            ),
        )
        service_obj.add_method(
            "Undownload",
            self.Undownload,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.UndownloadRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "Close",
            self.Close,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.CloseRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "RegisterExtension",
            self.RegisterExtension,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.RegisterExtensionRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "UnregisterExtension",
            self.UnregisterExtension,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.UnregisterExtensionRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "SendExtension",
            self.SendExtension,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.ExtensionMessage,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "AcquireLock",
            self.AcquireLock,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.LockRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "ReleaseLock",
            self.ReleaseLock,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.LockRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "OnAppend",
            self.OnAppend,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.AppendEvent,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "OnClose",
            self.OnClose,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.CloseEvent,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "OnPeerOpen",
            self.OnPeerOpen,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.PeerEvent,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "OnPeerRemove",
            self.OnPeerRemove,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.PeerEvent,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "OnExtension",
            self.OnExtension,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.ExtensionMessage,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "OnWait",
            self.OnWait,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.WaitEvent,
                hrpc__pb2.Void,
            ),
        )
        return service_obj


class HypercoreStub:
    def __init__(self, channel):
        self._client = purerpc.Client("hyperspace.Hypercore", channel)
        self.Get = self._client.get_method_stub(
            "Get",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.GetRequest,
                schema__pb2.GetResponse,
            ),
        )
        self.Append = self._client.get_method_stub(
            "Append",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.AppendRequest,
                schema__pb2.AppendResponse,
            ),
        )
        self.Update = self._client.get_method_stub(
            "Update",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.UpdateRequest,
                hrpc__pb2.Void,
            ),
        )
        self.Seek = self._client.get_method_stub(
            "Seek",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.SeekRequest,
                schema__pb2.SeekResponse,
            ),
        )
        self.Has = self._client.get_method_stub(
            "Has",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.HasRequest,
                schema__pb2.HasResponse,
            ),
        )
        self.Cancel = self._client.get_method_stub(
            "Cancel",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.CancelRequest,
                hrpc__pb2.Void,
            ),
        )
        self.Download = self._client.get_method_stub(
            "Download",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.DownloadRequest,
                hrpc__pb2.Void,
            ),
        )
        self.Downloaded = self._client.get_method_stub(
            "Downloaded",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.DownloadedRequest,
                schema__pb2.DownloadedResponse,
            ),
        )
        self.Undownload = self._client.get_method_stub(
            "Undownload",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.UndownloadRequest,
                hrpc__pb2.Void,
            ),
        )
        self.Close = self._client.get_method_stub(
            "Close",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.CloseRequest,
                hrpc__pb2.Void,
            ),
        )
        self.RegisterExtension = self._client.get_method_stub(
            "RegisterExtension",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.RegisterExtensionRequest,
                hrpc__pb2.Void,
            ),
        )
        self.UnregisterExtension = self._client.get_method_stub(
            "UnregisterExtension",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.UnregisterExtensionRequest,
                hrpc__pb2.Void,
            ),
        )
        self.SendExtension = self._client.get_method_stub(
            "SendExtension",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.ExtensionMessage,
                hrpc__pb2.Void,
            ),
        )
        self.AcquireLock = self._client.get_method_stub(
            "AcquireLock",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.LockRequest,
                hrpc__pb2.Void,
            ),
        )
        self.ReleaseLock = self._client.get_method_stub(
            "ReleaseLock",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.LockRequest,
                hrpc__pb2.Void,
            ),
        )
        self.OnAppend = self._client.get_method_stub(
            "OnAppend",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.AppendEvent,
                hrpc__pb2.Void,
            ),
        )
        self.OnClose = self._client.get_method_stub(
            "OnClose",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.CloseEvent,
                hrpc__pb2.Void,
            ),
        )
        self.OnPeerOpen = self._client.get_method_stub(
            "OnPeerOpen",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.PeerEvent,
                hrpc__pb2.Void,
            ),
        )
        self.OnPeerRemove = self._client.get_method_stub(
            "OnPeerRemove",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.PeerEvent,
                hrpc__pb2.Void,
            ),
        )
        self.OnExtension = self._client.get_method_stub(
            "OnExtension",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.ExtensionMessage,
                hrpc__pb2.Void,
            ),
        )
        self.OnWait = self._client.get_method_stub(
            "OnWait",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.WaitEvent,
                hrpc__pb2.Void,
            ),
        )


class NetworkServicer(purerpc.Servicer):
    async def Open(self, input_message):
        raise NotImplementedError()

    async def Configure(self, input_message):
        raise NotImplementedError()

    async def Status(self, input_message):
        raise NotImplementedError()

    async def AllStatuses(self, input_message):
        raise NotImplementedError()

    async def RegisterExtension(self, input_message):
        raise NotImplementedError()

    async def UnregisterExtension(self, input_message):
        raise NotImplementedError()

    async def SendExtension(self, input_message):
        raise NotImplementedError()

    async def OnPeerAdd(self, input_message):
        raise NotImplementedError()

    async def OnPeerRemove(self, input_message):
        raise NotImplementedError()

    async def OnExtension(self, input_message):
        raise NotImplementedError()

    @property
    def service(self) -> purerpc.Service:
        service_obj = purerpc.Service("hyperspace.Network")
        service_obj.add_method(
            "Open",
            self.Open,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                hrpc__pb2.Void,
                schema__pb2.OpenNetworkResponse,
            ),
        )
        service_obj.add_method(
            "Configure",
            self.Configure,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.ConfigureNetworkRequest,
                schema__pb2.NetworkStatusResponse,
            ),
        )
        service_obj.add_method(
            "Status",
            self.Status,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.NetworkStatusRequest,
                schema__pb2.NetworkStatusResponse,
            ),
        )
        service_obj.add_method(
            "AllStatuses",
            self.AllStatuses,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                hrpc__pb2.Void,
                schema__pb2.AllNetworkStatusesResponse,
            ),
        )
        service_obj.add_method(
            "RegisterExtension",
            self.RegisterExtension,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.RegisterExtensionRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "UnregisterExtension",
            self.UnregisterExtension,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.UnregisterExtensionRequest,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "SendExtension",
            self.SendExtension,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.ExtensionMessage,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "OnPeerAdd",
            self.OnPeerAdd,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.PeerEvent,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "OnPeerRemove",
            self.OnPeerRemove,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.PeerEvent,
                hrpc__pb2.Void,
            ),
        )
        service_obj.add_method(
            "OnExtension",
            self.OnExtension,
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.ExtensionMessage,
                hrpc__pb2.Void,
            ),
        )
        return service_obj


class NetworkStub:
    def __init__(self, channel):
        self._client = purerpc.Client("hyperspace.Network", channel)
        self.Open = self._client.get_method_stub(
            "Open",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                hrpc__pb2.Void,
                schema__pb2.OpenNetworkResponse,
            ),
        )
        self.Configure = self._client.get_method_stub(
            "Configure",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.ConfigureNetworkRequest,
                schema__pb2.NetworkStatusResponse,
            ),
        )
        self.Status = self._client.get_method_stub(
            "Status",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.NetworkStatusRequest,
                schema__pb2.NetworkStatusResponse,
            ),
        )
        self.AllStatuses = self._client.get_method_stub(
            "AllStatuses",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                hrpc__pb2.Void,
                schema__pb2.AllNetworkStatusesResponse,
            ),
        )
        self.RegisterExtension = self._client.get_method_stub(
            "RegisterExtension",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.RegisterExtensionRequest,
                hrpc__pb2.Void,
            ),
        )
        self.UnregisterExtension = self._client.get_method_stub(
            "UnregisterExtension",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.UnregisterExtensionRequest,
                hrpc__pb2.Void,
            ),
        )
        self.SendExtension = self._client.get_method_stub(
            "SendExtension",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.ExtensionMessage,
                hrpc__pb2.Void,
            ),
        )
        self.OnPeerAdd = self._client.get_method_stub(
            "OnPeerAdd",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.PeerEvent,
                hrpc__pb2.Void,
            ),
        )
        self.OnPeerRemove = self._client.get_method_stub(
            "OnPeerRemove",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.PeerEvent,
                hrpc__pb2.Void,
            ),
        )
        self.OnExtension = self._client.get_method_stub(
            "OnExtension",
            purerpc.RPCSignature(
                purerpc.Cardinality.UNARY_UNARY,
                schema__pb2.ExtensionMessage,
                hrpc__pb2.Void,
            ),
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: schema.proto
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import hrpc_pb2 as hrpc__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name="schema.proto",
    package="hyperspace",
    syntax="proto2",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x0cschema.proto\x12\nhyperspace\x1a\nhrpc.proto"D\n\x04Peer\x12\x17\n\x0fremotePublicKey\x18\x01 \x02(\x0c\x12\x15\n\rremoteAddress\x18\x02 \x02(\t\x12\x0c\n\x04type\x18\x03 \x02(\t"\\\n\x18HyperspaceStatusResponse\x12\x12\n\napiVersion\x18\x01 \x02(\t\x12\x15\n\rholepunchable\x18\x02 \x01(\x08\x12\x15\n\rremoteAddress\x18\x03 \x01(\t"B\n\x0bOpenRequest\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04weak\x18\x04 \x01(\x08"r\n\x0cOpenResponse\x12\x0b\n\x03key\x18\x01 \x02(\x0c\x12\x0e\n\x06length\x18\x02 \x02(\x04\x12\x12\n\nbyteLength\x18\x03 \x02(\x04\x12\x10\n\x08writable\x18\x04 \x02(\x08\x12\x1f\n\x05peers\x18\x05 \x03(\x0b\x32\x10.hyperspace.Peer"\x18\n\tFeedEvent\x12\x0b\n\x03key\x18\x01 \x02(\x0c"I\n\x13OpenNetworkResponse\x12\x11\n\tpublicKey\x18\x01 \x02(\x0c\x12\x1f\n\x05peers\x18\x02 \x03(\x0b\x32\x10.hyperspace.Peer"Y\n\rNetworkStatus\x12\x14\n\x0c\x64iscoveryKey\x18\x01 \x02(\x0c\x12\x10\n\x08\x61nnounce\x18\x02 \x01(\x08\x12\x0e\n\x06lookup\x18\x03 \x01(\x08\x12\x10\n\x08remember\x18\x04 \x01(\x08"\x85\x01\n\x17\x43onfigureNetworkRequest\x12\x30\n\rconfiguration\x18\x01 \x02(\x0b\x32\x19.hyperspace.NetworkStatus\x12\r\n\x05\x66lush\x18\x02 \x01(\x08\x12\x10\n\x08\x63opyFrom\x18\x03 \x01(\x0c\x12\x17\n\toverwrite\x18\x04 \x01(\x08:\x04true",\n\x14NetworkStatusRequest\x12\x14\n\x0c\x64iscoveryKey\x18\x01 \x02(\x0c"B\n\x15NetworkStatusResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x19.hyperspace.NetworkStatus"I\n\x1a\x41llNetworkStatusesResponse\x12+\n\x08statuses\x18\x01 \x03(\x0b\x32\x19.hyperspace.NetworkStatus"C\n\x1fRegisterNetworkExtensionRequest\x12\x12\n\nresourceId\x18\x01 \x02(\x04\x12\x0c\n\x04name\x18\x02 \x02(\t"`\n\x17NetworkExtensionMessage\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x12\n\nresourceId\x18\x02 \x02(\x04\x12\x17\n\x0fremotePublicKey\x18\x03 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x04 \x02(\x0c"\x1a\n\x0c\x43loseRequest\x12\n\n\x02id\x18\x01 \x02(\r"z\n\nGetRequest\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03seq\x18\x02 \x02(\x04\x12\x12\n\nresourceId\x18\x03 \x02(\x04\x12\x12\n\x04wait\x18\x04 \x01(\x08:\x04true\x12\x19\n\x0bifAvailable\x18\x05 \x01(\x08:\x04true\x12\x10\n\x08onWaitId\x18\x06 \x01(\x04"\x1c\n\x0bGetResponse\x12\r\n\x05\x62lock\x18\x01 \x01(\x0c"+\n\rAppendRequest\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0e\n\x06\x62locks\x18\x02 \x03(\x0c"A\n\x0e\x41ppendResponse\x12\x0e\n\x06length\x18\x01 \x02(\x04\x12\x12\n\nbyteLength\x18\x02 \x02(\x04\x12\x0b\n\x03seq\x18\x03 \x02(\x04"]\n\rUpdateRequest\x12\n\n\x02id\x18\x01 \x02(\r\x12\x11\n\tminLength\x18\x02 \x01(\x04\x12\x19\n\x0bifAvailable\x18\x03 \x01(\x08:\x04true\x12\x12\n\x04hash\x18\x04 \x01(\x08:\x04true"x\n\x0bSeekRequest\x12\n\n\x02id\x18\x01 \x02(\r\x12\x12\n\nbyteOffset\x18\x02 \x02(\x04\x12\r\n\x05start\x18\x03 \x01(\x04\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x04\x12\x12\n\x04wait\x18\x05 \x01(\x08:\x04true\x12\x19\n\x0bifAvailable\x18\x06 \x01(\x08:\x04true"0\n\x0cSeekResponse\x12\x0b\n\x03seq\x18\x01 \x02(\x04\x12\x13\n\x0b\x62lockOffset\x18\x02 \x02(\x04"%\n\nHasRequest\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03seq\x18\x02 \x02(\x04"\x1a\n\x0bHasResponse\x12\x0b\n\x03has\x18\x01 \x02(\x08"/\n\rCancelRequest\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x12\n\nresourceId\x18\x02 \x02(\x04"m\n\x0f\x44ownloadRequest\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x12\n\nresourceId\x18\x02 \x02(\x04\x12\r\n\x05start\x18\x03 \x01(\x04\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x04\x12\x0e\n\x06\x62locks\x18\x05 \x03(\x04\x12\x0e\n\x06linear\x18\x06 \x01(\x08";\n\x11\x44ownloadedRequest\x12\n\n\x02id\x18\x01 \x02(\x04\x12\r\n\x05start\x18\x02 \x01(\x04\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x04"#\n\x12\x44ownloadedResponse\x12\r\n\x05\x62ytes\x18\x01 \x02(\x04"3\n\x11UndownloadRequest\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x12\n\nresourceId\x18\x02 \x02(\x04"\x19\n\x0bLockRequest\x12\n\n\x02id\x18\x01 \x02(\x04"=\n\x0b\x41ppendEvent\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x0e\n\x06length\x18\x02 \x02(\x04\x12\x12\n\nbyteLength\x18\x03 \x02(\x04"7\n\tPeerEvent\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x1e\n\x04peer\x18\x02 \x02(\x0b\x32\x10.hyperspace.Peer"\x18\n\nCloseEvent\x12\n\n\x02id\x18\x01 \x02(\x04")\n\tWaitEvent\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x10\n\x08onWaitId\x18\x02 \x02(\x04"H\n\x18RegisterExtensionRequest\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x12\n\nresourceId\x18\x02 \x02(\x04\x12\x0c\n\x04name\x18\x03 \x02(\t"<\n\x1aUnregisterExtensionRequest\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x12\n\nresourceId\x18\x02 \x02(\x04"Y\n\x10\x45xtensionMessage\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x12\n\nresourceId\x18\x02 \x02(\x04\x12\x17\n\x0fremotePublicKey\x18\x03 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x04 \x02(\x0c\x32T\n\nHyperspace\x12@\n\x06Status\x12\n.hrpc.Void\x1a$.hyperspace.HyperspaceStatusResponse"\x04\x88\xb5\x18\x01\x1a\x04\x80\xb5\x18\x01\x32\x85\x01\n\tCorestore\x12?\n\x04Open\x12\x17.hyperspace.OpenRequest\x1a\x18.hyperspace.OpenResponse"\x04\x88\xb5\x18\x01\x12\x31\n\x06OnFeed\x12\x15.hyperspace.FeedEvent\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x02\x1a\x04\x80\xb5\x18\x02\x32\xa6\n\n\tHypercore\x12<\n\x03Get\x12\x16.hyperspace.GetRequest\x1a\x17.hyperspace.GetResponse"\x04\x88\xb5\x18\x01\x12\x45\n\x06\x41ppend\x12\x19.hyperspace.AppendRequest\x1a\x1a.hyperspace.AppendResponse"\x04\x88\xb5\x18\x02\x12\x35\n\x06Update\x12\x19.hyperspace.UpdateRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x03\x12?\n\x04Seek\x12\x17.hyperspace.SeekRequest\x1a\x18.hyperspace.SeekResponse"\x04\x88\xb5\x18\x04\x12<\n\x03Has\x12\x16.hyperspace.HasRequest\x1a\x17.hyperspace.HasResponse"\x04\x88\xb5\x18\x05\x12\x35\n\x06\x43\x61ncel\x12\x19.hyperspace.CancelRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x06\x12\x39\n\x08\x44ownload\x12\x1b.hyperspace.DownloadRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x07\x12Q\n\nDownloaded\x12\x1d.hyperspace.DownloadedRequest\x1a\x1e.hyperspace.DownloadedResponse"\x04\x88\xb5\x18\x08\x12=\n\nUndownload\x12\x1d.hyperspace.UndownloadRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\t\x12\x33\n\x05\x43lose\x12\x18.hyperspace.CloseRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\n\x12K\n\x11RegisterExtension\x12$.hyperspace.RegisterExtensionRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x0b\x12O\n\x13UnregisterExtension\x12&.hyperspace.UnregisterExtensionRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x0c\x12?\n\rSendExtension\x12\x1c.hyperspace.ExtensionMessage\x1a\n.hrpc.Void"\x04\x88\xb5\x18\r\x12\x38\n\x0b\x41\x63quireLock\x12\x17.hyperspace.LockRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x0e\x12\x38\n\x0bReleaseLock\x12\x17.hyperspace.LockRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x0f\x12\x35\n\x08OnAppend\x12\x17.hyperspace.AppendEvent\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x10\x12\x33\n\x07OnClose\x12\x16.hyperspace.CloseEvent\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x11\x12\x35\n\nOnPeerOpen\x12\x15.hyperspace.PeerEvent\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x12\x12\x37\n\x0cOnPeerRemove\x12\x15.hyperspace.PeerEvent\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x13\x12=\n\x0bOnExtension\x12\x1c.hyperspace.ExtensionMessage\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x14\x12\x31\n\x06OnWait\x12\x15.hyperspace.WaitEvent\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x15\x1a\x04\x80\xb5\x18\x03\x32\xd0\x05\n\x07Network\x12\x39\n\x04Open\x12\n.hrpc.Void\x1a\x1f.hyperspace.OpenNetworkResponse"\x04\x88\xb5\x18\x01\x12Y\n\tConfigure\x12#.hyperspace.ConfigureNetworkRequest\x1a!.hyperspace.NetworkStatusResponse"\x04\x88\xb5\x18\x02\x12S\n\x06Status\x12 .hyperspace.NetworkStatusRequest\x1a!.hyperspace.NetworkStatusResponse"\x04\x88\xb5\x18\x03\x12G\n\x0b\x41llStatuses\x12\n.hrpc.Void\x1a&.hyperspace.AllNetworkStatusesResponse"\x04\x88\xb5\x18\x04\x12K\n\x11RegisterExtension\x12$.hyperspace.RegisterExtensionRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x05\x12O\n\x13UnregisterExtension\x12&.hyperspace.UnregisterExtensionRequest\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x06\x12?\n\rSendExtension\x12\x1c.hyperspace.ExtensionMessage\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x07\x12\x34\n\tOnPeerAdd\x12\x15.hyperspace.PeerEvent\x1a\n.hrpc.Void"\x04\x88\xb5\x18\x08\x12\x37\n\x0cOnPeerRemove\x12\x15.hyperspace.PeerEvent\x1a\n.hrpc.Void"\x04\x88\xb5\x18\t\x12=\n\x0bOnExtension\x12\x1c.hyperspace.ExtensionMessage\x1a\n.hrpc.Void"\x04\x88\xb5\x18\n\x1a\x04\x80\xb5\x18\x04',
    dependencies=[hrpc__pb2.DESCRIPTOR,],
)


_PEER = _descriptor.Descriptor(
    name="Peer",
    full_name="hyperspace.Peer",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="remotePublicKey",
            full_name="hyperspace.Peer.remotePublicKey",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="remoteAddress",
            full_name="hyperspace.Peer.remoteAddress",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="hyperspace.Peer.type",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=40,
    serialized_end=108,
)


_HYPERSPACESTATUSRESPONSE = _descriptor.Descriptor(
    name="HyperspaceStatusResponse",
    full_name="hyperspace.HyperspaceStatusResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="apiVersion",
            full_name="hyperspace.HyperspaceStatusResponse.apiVersion",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="holepunchable",
            full_name="hyperspace.HyperspaceStatusResponse.holepunchable",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="remoteAddress",
            full_name="hyperspace.HyperspaceStatusResponse.remoteAddress",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=110,
    serialized_end=202,
)


_OPENREQUEST = _descriptor.Descriptor(
    name="OpenRequest",
    full_name="hyperspace.OpenRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.OpenRequest.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="key",
            full_name="hyperspace.OpenRequest.key",
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="hyperspace.OpenRequest.name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="weak",
            full_name="hyperspace.OpenRequest.weak",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=204,
    serialized_end=270,
)


_OPENRESPONSE = _descriptor.Descriptor(
    name="OpenResponse",
    full_name="hyperspace.OpenResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="hyperspace.OpenResponse.key",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="length",
            full_name="hyperspace.OpenResponse.length",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="byteLength",
            full_name="hyperspace.OpenResponse.byteLength",
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="writable",
            full_name="hyperspace.OpenResponse.writable",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=2,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="peers",
            full_name="hyperspace.OpenResponse.peers",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=272,
    serialized_end=386,
)


_FEEDEVENT = _descriptor.Descriptor(
    name="FeedEvent",
    full_name="hyperspace.FeedEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="hyperspace.FeedEvent.key",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=388,
    serialized_end=412,
)


_OPENNETWORKRESPONSE = _descriptor.Descriptor(
    name="OpenNetworkResponse",
    full_name="hyperspace.OpenNetworkResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="publicKey",
            full_name="hyperspace.OpenNetworkResponse.publicKey",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="peers",
            full_name="hyperspace.OpenNetworkResponse.peers",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=414,
    serialized_end=487,
)


_NETWORKSTATUS = _descriptor.Descriptor(
    name="NetworkStatus",
    full_name="hyperspace.NetworkStatus",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="discoveryKey",
            full_name="hyperspace.NetworkStatus.discoveryKey",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="announce",
            full_name="hyperspace.NetworkStatus.announce",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="lookup",
            full_name="hyperspace.NetworkStatus.lookup",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="remember",
            full_name="hyperspace.NetworkStatus.remember",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=489,
    serialized_end=578,
)


_CONFIGURENETWORKREQUEST = _descriptor.Descriptor(
    name="ConfigureNetworkRequest",
    full_name="hyperspace.ConfigureNetworkRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="configuration",
            full_name="hyperspace.ConfigureNetworkRequest.configuration",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=2,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="flush",
            full_name="hyperspace.ConfigureNetworkRequest.flush",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="copyFrom",
            full_name="hyperspace.ConfigureNetworkRequest.copyFrom",
            index=2,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="overwrite",
            full_name="hyperspace.ConfigureNetworkRequest.overwrite",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=True,
            default_value=True,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=581,
    serialized_end=714,
)


_NETWORKSTATUSREQUEST = _descriptor.Descriptor(
    name="NetworkStatusRequest",
    full_name="hyperspace.NetworkStatusRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="discoveryKey",
            full_name="hyperspace.NetworkStatusRequest.discoveryKey",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=716,
    serialized_end=760,
)


_NETWORKSTATUSRESPONSE = _descriptor.Descriptor(
    name="NetworkStatusResponse",
    full_name="hyperspace.NetworkStatusResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="status",
            full_name="hyperspace.NetworkStatusResponse.status",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=762,
    serialized_end=828,
)


_ALLNETWORKSTATUSESRESPONSE = _descriptor.Descriptor(
    name="AllNetworkStatusesResponse",
    full_name="hyperspace.AllNetworkStatusesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="statuses",
            full_name="hyperspace.AllNetworkStatusesResponse.statuses",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=830,
    serialized_end=903,
)


_REGISTERNETWORKEXTENSIONREQUEST = _descriptor.Descriptor(
    name="RegisterNetworkExtensionRequest",
    full_name="hyperspace.RegisterNetworkExtensionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="resourceId",
            full_name="hyperspace.RegisterNetworkExtensionRequest.resourceId",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="hyperspace.RegisterNetworkExtensionRequest.name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=905,
    serialized_end=972,
)


_NETWORKEXTENSIONMESSAGE = _descriptor.Descriptor(
    name="NetworkExtensionMessage",
    full_name="hyperspace.NetworkExtensionMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.NetworkExtensionMessage.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resourceId",
            full_name="hyperspace.NetworkExtensionMessage.resourceId",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="remotePublicKey",
            full_name="hyperspace.NetworkExtensionMessage.remotePublicKey",
            index=2,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="hyperspace.NetworkExtensionMessage.data",
            index=3,
            number=4,
            type=12,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=974,
    serialized_end=1070,
)


_CLOSEREQUEST = _descriptor.Descriptor(
    name="CloseRequest",
    full_name="hyperspace.CloseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.CloseRequest.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1072,
    serialized_end=1098,
)


_GETREQUEST = _descriptor.Descriptor(
    name="GetRequest",
    full_name="hyperspace.GetRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.GetRequest.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="seq",
            full_name="hyperspace.GetRequest.seq",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resourceId",
            full_name="hyperspace.GetRequest.resourceId",
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="wait",
            full_name="hyperspace.GetRequest.wait",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=True,
            default_value=True,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ifAvailable",
            full_name="hyperspace.GetRequest.ifAvailable",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=True,
            default_value=True,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="onWaitId",
            full_name="hyperspace.GetRequest.onWaitId",
            index=5,
            number=6,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1100,
    serialized_end=1222,
)


_GETRESPONSE = _descriptor.Descriptor(
    name="GetResponse",
    full_name="hyperspace.GetResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="block",
            full_name="hyperspace.GetResponse.block",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1224,
    serialized_end=1252,
)


_APPENDREQUEST = _descriptor.Descriptor(
    name="AppendRequest",
    full_name="hyperspace.AppendRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.AppendRequest.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="blocks",
            full_name="hyperspace.AppendRequest.blocks",
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1254,
    serialized_end=1297,
)


_APPENDRESPONSE = _descriptor.Descriptor(
    name="AppendResponse",
    full_name="hyperspace.AppendResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="length",
            full_name="hyperspace.AppendResponse.length",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="byteLength",
            full_name="hyperspace.AppendResponse.byteLength",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="seq",
            full_name="hyperspace.AppendResponse.seq",
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1299,
    serialized_end=1364,
)


_UPDATEREQUEST = _descriptor.Descriptor(
    name="UpdateRequest",
    full_name="hyperspace.UpdateRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.UpdateRequest.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="minLength",
            full_name="hyperspace.UpdateRequest.minLength",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ifAvailable",
            full_name="hyperspace.UpdateRequest.ifAvailable",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=True,
            default_value=True,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="hash",
            full_name="hyperspace.UpdateRequest.hash",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=True,
            default_value=True,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1366,
    serialized_end=1459,
)


_SEEKREQUEST = _descriptor.Descriptor(
    name="SeekRequest",
    full_name="hyperspace.SeekRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.SeekRequest.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="byteOffset",
            full_name="hyperspace.SeekRequest.byteOffset",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="start",
            full_name="hyperspace.SeekRequest.start",
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end",
            full_name="hyperspace.SeekRequest.end",
            index=3,
            number=4,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="wait",
            full_name="hyperspace.SeekRequest.wait",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=True,
            default_value=True,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ifAvailable",
            full_name="hyperspace.SeekRequest.ifAvailable",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=True,
            default_value=True,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1461,
    serialized_end=1581,
)


_SEEKRESPONSE = _descriptor.Descriptor(
    name="SeekResponse",
    full_name="hyperspace.SeekResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="seq",
            full_name="hyperspace.SeekResponse.seq",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="blockOffset",
            full_name="hyperspace.SeekResponse.blockOffset",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1583,
    serialized_end=1631,
)


_HASREQUEST = _descriptor.Descriptor(
    name="HasRequest",
    full_name="hyperspace.HasRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.HasRequest.id",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="seq",
            full_name="hyperspace.HasRequest.seq",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1633,
    serialized_end=1670,
)


_HASRESPONSE = _descriptor.Descriptor(
    name="HasResponse",
    full_name="hyperspace.HasResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="has",
            full_name="hyperspace.HasResponse.has",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=2,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1672,
    serialized_end=1698,
)


_CANCELREQUEST = _descriptor.Descriptor(
    name="CancelRequest",
    full_name="hyperspace.CancelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.CancelRequest.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resourceId",
            full_name="hyperspace.CancelRequest.resourceId",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1700,
    serialized_end=1747,
)


_DOWNLOADREQUEST = _descriptor.Descriptor(
    name="DownloadRequest",
    full_name="hyperspace.DownloadRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.DownloadRequest.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resourceId",
            full_name="hyperspace.DownloadRequest.resourceId",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="start",
            full_name="hyperspace.DownloadRequest.start",
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end",
            full_name="hyperspace.DownloadRequest.end",
            index=3,
            number=4,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="blocks",
            full_name="hyperspace.DownloadRequest.blocks",
            index=4,
            number=5,
            type=4,
            cpp_type=4,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="linear",
            full_name="hyperspace.DownloadRequest.linear",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1749,
    serialized_end=1858,
)


_DOWNLOADEDREQUEST = _descriptor.Descriptor(
    name="DownloadedRequest",
    full_name="hyperspace.DownloadedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.DownloadedRequest.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="start",
            full_name="hyperspace.DownloadedRequest.start",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end",
            full_name="hyperspace.DownloadedRequest.end",
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1860,
    serialized_end=1919,
)


_DOWNLOADEDRESPONSE = _descriptor.Descriptor(
    name="DownloadedResponse",
    full_name="hyperspace.DownloadedResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="bytes",
            full_name="hyperspace.DownloadedResponse.bytes",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1921,
    serialized_end=1956,
)


_UNDOWNLOADREQUEST = _descriptor.Descriptor(
    name="UndownloadRequest",
    full_name="hyperspace.UndownloadRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.UndownloadRequest.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resourceId",
            full_name="hyperspace.UndownloadRequest.resourceId",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1958,
    serialized_end=2009,
)


_LOCKREQUEST = _descriptor.Descriptor(
    name="LockRequest",
    full_name="hyperspace.LockRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.LockRequest.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2011,
    serialized_end=2036,
)


_APPENDEVENT = _descriptor.Descriptor(
    name="AppendEvent",
    full_name="hyperspace.AppendEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.AppendEvent.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="length",
            full_name="hyperspace.AppendEvent.length",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="byteLength",
            full_name="hyperspace.AppendEvent.byteLength",
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2038,
    serialized_end=2099,
)


_PEEREVENT = _descriptor.Descriptor(
    name="PeerEvent",
    full_name="hyperspace.PeerEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.PeerEvent.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="peer",
            full_name="hyperspace.PeerEvent.peer",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=2,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2101,
    serialized_end=2156,
)


_CLOSEEVENT = _descriptor.Descriptor(
    name="CloseEvent",
    full_name="hyperspace.CloseEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.CloseEvent.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2158,
    serialized_end=2182,
)


_WAITEVENT = _descriptor.Descriptor(
    name="WaitEvent",
    full_name="hyperspace.WaitEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.WaitEvent.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="onWaitId",
            full_name="hyperspace.WaitEvent.onWaitId",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2184,
    serialized_end=2225,
)


_REGISTEREXTENSIONREQUEST = _descriptor.Descriptor(
    name="RegisterExtensionRequest",
    full_name="hyperspace.RegisterExtensionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.RegisterExtensionRequest.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resourceId",
            full_name="hyperspace.RegisterExtensionRequest.resourceId",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="hyperspace.RegisterExtensionRequest.name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2227,
    serialized_end=2299,
)


_UNREGISTEREXTENSIONREQUEST = _descriptor.Descriptor(
    name="UnregisterExtensionRequest",
    full_name="hyperspace.UnregisterExtensionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.UnregisterExtensionRequest.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resourceId",
            full_name="hyperspace.UnregisterExtensionRequest.resourceId",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2301,
    serialized_end=2361,
)


_EXTENSIONMESSAGE = _descriptor.Descriptor(
    name="ExtensionMessage",
    full_name="hyperspace.ExtensionMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="hyperspace.ExtensionMessage.id",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resourceId",
            full_name="hyperspace.ExtensionMessage.resourceId",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=2,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="remotePublicKey",
            full_name="hyperspace.ExtensionMessage.remotePublicKey",
            index=2,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="hyperspace.ExtensionMessage.data",
            index=3,
            number=4,
            type=12,
            cpp_type=9,
            label=2,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2363,
    serialized_end=2452,
)

_OPENRESPONSE.fields_by_name["peers"].message_type = _PEER
_OPENNETWORKRESPONSE.fields_by_name["peers"].message_type = _PEER
_CONFIGURENETWORKREQUEST.fields_by_name[
    "configuration"
].message_type = _NETWORKSTATUS
_NETWORKSTATUSRESPONSE.fields_by_name["status"].message_type = _NETWORKSTATUS
_ALLNETWORKSTATUSESRESPONSE.fields_by_name[
    "statuses"
].message_type = _NETWORKSTATUS
_PEEREVENT.fields_by_name["peer"].message_type = _PEER
DESCRIPTOR.message_types_by_name["Peer"] = _PEER
DESCRIPTOR.message_types_by_name[
    "HyperspaceStatusResponse"
] = _HYPERSPACESTATUSRESPONSE
DESCRIPTOR.message_types_by_name["OpenRequest"] = _OPENREQUEST
DESCRIPTOR.message_types_by_name["OpenResponse"] = _OPENRESPONSE
DESCRIPTOR.message_types_by_name["FeedEvent"] = _FEEDEVENT
DESCRIPTOR.message_types_by_name["OpenNetworkResponse"] = _OPENNETWORKRESPONSE
DESCRIPTOR.message_types_by_name["NetworkStatus"] = _NETWORKSTATUS
DESCRIPTOR.message_types_by_name[
    "ConfigureNetworkRequest"
] = _CONFIGURENETWORKREQUEST
DESCRIPTOR.message_types_by_name["NetworkStatusRequest"] = _NETWORKSTATUSREQUEST
DESCRIPTOR.message_types_by_name[
    "NetworkStatusResponse"
] = _NETWORKSTATUSRESPONSE
DESCRIPTOR.message_types_by_name[
    "AllNetworkStatusesResponse"
] = _ALLNETWORKSTATUSESRESPONSE
DESCRIPTOR.message_types_by_name[
    "RegisterNetworkExtensionRequest"
] = _REGISTERNETWORKEXTENSIONREQUEST
DESCRIPTOR.message_types_by_name[
    "NetworkExtensionMessage"
] = _NETWORKEXTENSIONMESSAGE
DESCRIPTOR.message_types_by_name["CloseRequest"] = _CLOSEREQUEST
DESCRIPTOR.message_types_by_name["GetRequest"] = _GETREQUEST
DESCRIPTOR.message_types_by_name["GetResponse"] = _GETRESPONSE
DESCRIPTOR.message_types_by_name["AppendRequest"] = _APPENDREQUEST
DESCRIPTOR.message_types_by_name["AppendResponse"] = _APPENDRESPONSE
DESCRIPTOR.message_types_by_name["UpdateRequest"] = _UPDATEREQUEST
DESCRIPTOR.message_types_by_name["SeekRequest"] = _SEEKREQUEST
DESCRIPTOR.message_types_by_name["SeekResponse"] = _SEEKRESPONSE
DESCRIPTOR.message_types_by_name["HasRequest"] = _HASREQUEST
DESCRIPTOR.message_types_by_name["HasResponse"] = _HASRESPONSE
DESCRIPTOR.message_types_by_name["CancelRequest"] = _CANCELREQUEST
DESCRIPTOR.message_types_by_name["DownloadRequest"] = _DOWNLOADREQUEST
DESCRIPTOR.message_types_by_name["DownloadedRequest"] = _DOWNLOADEDREQUEST
DESCRIPTOR.message_types_by_name["DownloadedResponse"] = _DOWNLOADEDRESPONSE
DESCRIPTOR.message_types_by_name["UndownloadRequest"] = _UNDOWNLOADREQUEST
DESCRIPTOR.message_types_by_name["LockRequest"] = _LOCKREQUEST
DESCRIPTOR.message_types_by_name["AppendEvent"] = _APPENDEVENT
DESCRIPTOR.message_types_by_name["PeerEvent"] = _PEEREVENT
DESCRIPTOR.message_types_by_name["CloseEvent"] = _CLOSEEVENT
DESCRIPTOR.message_types_by_name["WaitEvent"] = _WAITEVENT
DESCRIPTOR.message_types_by_name[
    "RegisterExtensionRequest"
] = _REGISTEREXTENSIONREQUEST
DESCRIPTOR.message_types_by_name[
    "UnregisterExtensionRequest"
] = _UNREGISTEREXTENSIONREQUEST
DESCRIPTOR.message_types_by_name["ExtensionMessage"] = _EXTENSIONMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Peer = _reflection.GeneratedProtocolMessageType(
    "Peer",
    (_message.Message,),
    {
        "DESCRIPTOR": _PEER,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.Peer)
    },
)
_sym_db.RegisterMessage(Peer)

HyperspaceStatusResponse = _reflection.GeneratedProtocolMessageType(
    "HyperspaceStatusResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _HYPERSPACESTATUSRESPONSE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.HyperspaceStatusResponse)
    },
)
_sym_db.RegisterMessage(HyperspaceStatusResponse)

OpenRequest = _reflection.GeneratedProtocolMessageType(
    "OpenRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _OPENREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.OpenRequest)
    },
)
_sym_db.RegisterMessage(OpenRequest)

OpenResponse = _reflection.GeneratedProtocolMessageType(
    "OpenResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _OPENRESPONSE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.OpenResponse)
    },
)
_sym_db.RegisterMessage(OpenResponse)

FeedEvent = _reflection.GeneratedProtocolMessageType(
    "FeedEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _FEEDEVENT,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.FeedEvent)
    },
)
_sym_db.RegisterMessage(FeedEvent)

OpenNetworkResponse = _reflection.GeneratedProtocolMessageType(
    "OpenNetworkResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _OPENNETWORKRESPONSE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.OpenNetworkResponse)
    },
)
_sym_db.RegisterMessage(OpenNetworkResponse)

NetworkStatus = _reflection.GeneratedProtocolMessageType(
    "NetworkStatus",
    (_message.Message,),
    {
        "DESCRIPTOR": _NETWORKSTATUS,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.NetworkStatus)
    },
)
_sym_db.RegisterMessage(NetworkStatus)

ConfigureNetworkRequest = _reflection.GeneratedProtocolMessageType(
    "ConfigureNetworkRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONFIGURENETWORKREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.ConfigureNetworkRequest)
    },
)
_sym_db.RegisterMessage(ConfigureNetworkRequest)

NetworkStatusRequest = _reflection.GeneratedProtocolMessageType(
    "NetworkStatusRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _NETWORKSTATUSREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.NetworkStatusRequest)
    },
)
_sym_db.RegisterMessage(NetworkStatusRequest)

NetworkStatusResponse = _reflection.GeneratedProtocolMessageType(
    "NetworkStatusResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _NETWORKSTATUSRESPONSE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.NetworkStatusResponse)
    },
)
_sym_db.RegisterMessage(NetworkStatusResponse)

AllNetworkStatusesResponse = _reflection.GeneratedProtocolMessageType(
    "AllNetworkStatusesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _ALLNETWORKSTATUSESRESPONSE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.AllNetworkStatusesResponse)
    },
)
_sym_db.RegisterMessage(AllNetworkStatusesResponse)

RegisterNetworkExtensionRequest = _reflection.GeneratedProtocolMessageType(
    "RegisterNetworkExtensionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _REGISTERNETWORKEXTENSIONREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.RegisterNetworkExtensionRequest)
    },
)
_sym_db.RegisterMessage(RegisterNetworkExtensionRequest)

NetworkExtensionMessage = _reflection.GeneratedProtocolMessageType(
    "NetworkExtensionMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _NETWORKEXTENSIONMESSAGE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.NetworkExtensionMessage)
    },
)
_sym_db.RegisterMessage(NetworkExtensionMessage)

CloseRequest = _reflection.GeneratedProtocolMessageType(
    "CloseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CLOSEREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.CloseRequest)
    },
)
_sym_db.RegisterMessage(CloseRequest)

GetRequest = _reflection.GeneratedProtocolMessageType(
    "GetRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.GetRequest)
    },
)
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType(
    "GetResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETRESPONSE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.GetResponse)
    },
)
_sym_db.RegisterMessage(GetResponse)

AppendRequest = _reflection.GeneratedProtocolMessageType(
    "AppendRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPENDREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.AppendRequest)
    },
)
_sym_db.RegisterMessage(AppendRequest)

AppendResponse = _reflection.GeneratedProtocolMessageType(
    "AppendResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPENDRESPONSE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.AppendResponse)
    },
)
_sym_db.RegisterMessage(AppendResponse)

UpdateRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.UpdateRequest)
    },
)
_sym_db.RegisterMessage(UpdateRequest)

SeekRequest = _reflection.GeneratedProtocolMessageType(
    "SeekRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEEKREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.SeekRequest)
    },
)
_sym_db.RegisterMessage(SeekRequest)

SeekResponse = _reflection.GeneratedProtocolMessageType(
    "SeekResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEEKRESPONSE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.SeekResponse)
    },
)
_sym_db.RegisterMessage(SeekResponse)

HasRequest = _reflection.GeneratedProtocolMessageType(
    "HasRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _HASREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.HasRequest)
    },
)
_sym_db.RegisterMessage(HasRequest)

HasResponse = _reflection.GeneratedProtocolMessageType(
    "HasResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _HASRESPONSE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.HasResponse)
    },
)
_sym_db.RegisterMessage(HasResponse)

CancelRequest = _reflection.GeneratedProtocolMessageType(
    "CancelRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CANCELREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.CancelRequest)
    },
)
_sym_db.RegisterMessage(CancelRequest)

DownloadRequest = _reflection.GeneratedProtocolMessageType(
    "DownloadRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DOWNLOADREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.DownloadRequest)
    },
)
_sym_db.RegisterMessage(DownloadRequest)

DownloadedRequest = _reflection.GeneratedProtocolMessageType(
    "DownloadedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DOWNLOADEDREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.DownloadedRequest)
    },
)
_sym_db.RegisterMessage(DownloadedRequest)

DownloadedResponse = _reflection.GeneratedProtocolMessageType(
    "DownloadedResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _DOWNLOADEDRESPONSE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.DownloadedResponse)
    },
)
_sym_db.RegisterMessage(DownloadedResponse)

UndownloadRequest = _reflection.GeneratedProtocolMessageType(
    "UndownloadRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UNDOWNLOADREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.UndownloadRequest)
    },
)
_sym_db.RegisterMessage(UndownloadRequest)

LockRequest = _reflection.GeneratedProtocolMessageType(
    "LockRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LOCKREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.LockRequest)
    },
)
_sym_db.RegisterMessage(LockRequest)

AppendEvent = _reflection.GeneratedProtocolMessageType(
    "AppendEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _APPENDEVENT,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.AppendEvent)
    },
)
_sym_db.RegisterMessage(AppendEvent)

PeerEvent = _reflection.GeneratedProtocolMessageType(
    "PeerEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _PEEREVENT,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.PeerEvent)
    },
)
_sym_db.RegisterMessage(PeerEvent)

CloseEvent = _reflection.GeneratedProtocolMessageType(
    "CloseEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _CLOSEEVENT,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.CloseEvent)
    },
)
_sym_db.RegisterMessage(CloseEvent)

WaitEvent = _reflection.GeneratedProtocolMessageType(
    "WaitEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _WAITEVENT,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.WaitEvent)
    },
)
_sym_db.RegisterMessage(WaitEvent)

RegisterExtensionRequest = _reflection.GeneratedProtocolMessageType(
    "RegisterExtensionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _REGISTEREXTENSIONREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.RegisterExtensionRequest)
    },
)
_sym_db.RegisterMessage(RegisterExtensionRequest)

UnregisterExtensionRequest = _reflection.GeneratedProtocolMessageType(
    "UnregisterExtensionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UNREGISTEREXTENSIONREQUEST,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.UnregisterExtensionRequest)
    },
)
_sym_db.RegisterMessage(UnregisterExtensionRequest)

ExtensionMessage = _reflection.GeneratedProtocolMessageType(
    "ExtensionMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTENSIONMESSAGE,
        "__module__": "schema_pb2"
        # @@protoc_insertion_point(class_scope:hyperspace.ExtensionMessage)
    },
)
_sym_db.RegisterMessage(ExtensionMessage)


_HYPERSPACE = _descriptor.ServiceDescriptor(
    name="Hyperspace",
    full_name="hyperspace.Hyperspace",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\200\265\030\001",
    create_key=_descriptor._internal_create_key,
    serialized_start=2454,
    serialized_end=2538,
    methods=[
        _descriptor.MethodDescriptor(
            name="Status",
            full_name="hyperspace.Hyperspace.Status",
            index=0,
            containing_service=None,
            input_type=hrpc__pb2._VOID,
            output_type=_HYPERSPACESTATUSRESPONSE,
            serialized_options=b"\210\265\030\001",
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_HYPERSPACE)

DESCRIPTOR.services_by_name["Hyperspace"] = _HYPERSPACE


_CORESTORE = _descriptor.ServiceDescriptor(
    name="Corestore",
    full_name="hyperspace.Corestore",
    file=DESCRIPTOR,
    index=1,
    serialized_options=b"\200\265\030\002",
    create_key=_descriptor._internal_create_key,
    serialized_start=2541,
    serialized_end=2674,
    methods=[
        _descriptor.MethodDescriptor(
            name="Open",
            full_name="hyperspace.Corestore.Open",
            index=0,
            containing_service=None,
            input_type=_OPENREQUEST,
            output_type=_OPENRESPONSE,
            serialized_options=b"\210\265\030\001",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OnFeed",
            full_name="hyperspace.Corestore.OnFeed",
            index=1,
            containing_service=None,
            input_type=_FEEDEVENT,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\002",
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_CORESTORE)

DESCRIPTOR.services_by_name["Corestore"] = _CORESTORE


_HYPERCORE = _descriptor.ServiceDescriptor(
    name="Hypercore",
    full_name="hyperspace.Hypercore",
    file=DESCRIPTOR,
    index=2,
    serialized_options=b"\200\265\030\003",
    create_key=_descriptor._internal_create_key,
    serialized_start=2677,
    serialized_end=3995,
    methods=[
        _descriptor.MethodDescriptor(
            name="Get",
            full_name="hyperspace.Hypercore.Get",
            index=0,
            containing_service=None,
            input_type=_GETREQUEST,
            output_type=_GETRESPONSE,
            serialized_options=b"\210\265\030\001",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Append",
            full_name="hyperspace.Hypercore.Append",
            index=1,
            containing_service=None,
            input_type=_APPENDREQUEST,
            output_type=_APPENDRESPONSE,
            serialized_options=b"\210\265\030\002",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Update",
            full_name="hyperspace.Hypercore.Update",
            index=2,
            containing_service=None,
            input_type=_UPDATEREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\003",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Seek",
            full_name="hyperspace.Hypercore.Seek",
            index=3,
            containing_service=None,
            input_type=_SEEKREQUEST,
            output_type=_SEEKRESPONSE,
            serialized_options=b"\210\265\030\004",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Has",
            full_name="hyperspace.Hypercore.Has",
            index=4,
            containing_service=None,
            input_type=_HASREQUEST,
            output_type=_HASRESPONSE,
            serialized_options=b"\210\265\030\005",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Cancel",
            full_name="hyperspace.Hypercore.Cancel",
            index=5,
            containing_service=None,
            input_type=_CANCELREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\006",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Download",
            full_name="hyperspace.Hypercore.Download",
            index=6,
            containing_service=None,
            input_type=_DOWNLOADREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\007",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Downloaded",
            full_name="hyperspace.Hypercore.Downloaded",
            index=7,
            containing_service=None,
            input_type=_DOWNLOADEDREQUEST,
            output_type=_DOWNLOADEDRESPONSE,
            serialized_options=b"\210\265\030\010",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Undownload",
            full_name="hyperspace.Hypercore.Undownload",
            index=8,
            containing_service=None,
            input_type=_UNDOWNLOADREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\t",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Close",
            full_name="hyperspace.Hypercore.Close",
            index=9,
            containing_service=None,
            input_type=_CLOSEREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\n",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RegisterExtension",
            full_name="hyperspace.Hypercore.RegisterExtension",
            index=10,
            containing_service=None,
            input_type=_REGISTEREXTENSIONREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\013",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UnregisterExtension",
            full_name="hyperspace.Hypercore.UnregisterExtension",
            index=11,
            containing_service=None,
            input_type=_UNREGISTEREXTENSIONREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\014",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="SendExtension",
            full_name="hyperspace.Hypercore.SendExtension",
            index=12,
            containing_service=None,
            input_type=_EXTENSIONMESSAGE,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\r",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="AcquireLock",
            full_name="hyperspace.Hypercore.AcquireLock",
            index=13,
            containing_service=None,
            input_type=_LOCKREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\016",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ReleaseLock",
            full_name="hyperspace.Hypercore.ReleaseLock",
            index=14,
            containing_service=None,
            input_type=_LOCKREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\017",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OnAppend",
            full_name="hyperspace.Hypercore.OnAppend",
            index=15,
            containing_service=None,
            input_type=_APPENDEVENT,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\020",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OnClose",
            full_name="hyperspace.Hypercore.OnClose",
            index=16,
            containing_service=None,
            input_type=_CLOSEEVENT,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\021",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OnPeerOpen",
            full_name="hyperspace.Hypercore.OnPeerOpen",
            index=17,
            containing_service=None,
            input_type=_PEEREVENT,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\022",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OnPeerRemove",
            full_name="hyperspace.Hypercore.OnPeerRemove",
            index=18,
            containing_service=None,
            input_type=_PEEREVENT,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\023",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OnExtension",
            full_name="hyperspace.Hypercore.OnExtension",
            index=19,
            containing_service=None,
            input_type=_EXTENSIONMESSAGE,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\024",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OnWait",
            full_name="hyperspace.Hypercore.OnWait",
            index=20,
            containing_service=None,
            input_type=_WAITEVENT,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\025",
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_HYPERCORE)

DESCRIPTOR.services_by_name["Hypercore"] = _HYPERCORE


_NETWORK = _descriptor.ServiceDescriptor(
    name="Network",
    full_name="hyperspace.Network",
    file=DESCRIPTOR,
    index=3,
    serialized_options=b"\200\265\030\004",
    create_key=_descriptor._internal_create_key,
    serialized_start=3998,
    serialized_end=4718,
    methods=[
        _descriptor.MethodDescriptor(
            name="Open",
            full_name="hyperspace.Network.Open",
            index=0,
            containing_service=None,
            input_type=hrpc__pb2._VOID,
            output_type=_OPENNETWORKRESPONSE,
            serialized_options=b"\210\265\030\001",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Configure",
            full_name="hyperspace.Network.Configure",
            index=1,
            containing_service=None,
            input_type=_CONFIGURENETWORKREQUEST,
            output_type=_NETWORKSTATUSRESPONSE,
            serialized_options=b"\210\265\030\002",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Status",
            full_name="hyperspace.Network.Status",
            index=2,
            containing_service=None,
            input_type=_NETWORKSTATUSREQUEST,
            output_type=_NETWORKSTATUSRESPONSE,
            serialized_options=b"\210\265\030\003",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="AllStatuses",
            full_name="hyperspace.Network.AllStatuses",
            index=3,
            containing_service=None,
            input_type=hrpc__pb2._VOID,
            output_type=_ALLNETWORKSTATUSESRESPONSE,
            serialized_options=b"\210\265\030\004",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="RegisterExtension",
            full_name="hyperspace.Network.RegisterExtension",
            index=4,
            containing_service=None,
            input_type=_REGISTEREXTENSIONREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\005",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UnregisterExtension",
            full_name="hyperspace.Network.UnregisterExtension",
            index=5,
            containing_service=None,
            input_type=_UNREGISTEREXTENSIONREQUEST,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\006",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="SendExtension",
            full_name="hyperspace.Network.SendExtension",
            index=6,
            containing_service=None,
            input_type=_EXTENSIONMESSAGE,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\007",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OnPeerAdd",
            full_name="hyperspace.Network.OnPeerAdd",
            index=7,
            containing_service=None,
            input_type=_PEEREVENT,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\010",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OnPeerRemove",
            full_name="hyperspace.Network.OnPeerRemove",
            index=8,
            containing_service=None,
            input_type=_PEEREVENT,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\t",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OnExtension",
            full_name="hyperspace.Network.OnExtension",
            index=9,
            containing_service=None,
            input_type=_EXTENSIONMESSAGE,
            output_type=hrpc__pb2._VOID,
            serialized_options=b"\210\265\030\n",
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_NETWORK)

DESCRIPTOR.services_by_name["Network"] = _NETWORK

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hrpc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import (
    descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2,
)

DESCRIPTOR = _descriptor.FileDescriptor(
    name="hrpc.proto",
    package="hrpc",
    syntax="proto2",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\nhrpc.proto\x12\x04hrpc\x1a google/protobuf/descriptor.proto"\x06\n\x04Void:2\n\x07service\x12\x1f.google.protobuf.ServiceOptions\x18\xd0\x86\x03 \x01(\r:0\n\x06method\x12\x1e.google.protobuf.MethodOptions\x18\xd1\x86\x03 \x01(\r',
    dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,],
)


SERVICE_FIELD_NUMBER = 50000
service = _descriptor.FieldDescriptor(
    name="service",
    full_name="hrpc.service",
    index=0,
    number=50000,
    type=13,
    cpp_type=3,
    label=1,
    has_default_value=False,
    default_value=0,
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
)
METHOD_FIELD_NUMBER = 50001
method = _descriptor.FieldDescriptor(
    name="method",
    full_name="hrpc.method",
    index=1,
    number=50001,
    type=13,
    cpp_type=3,
    label=1,
    has_default_value=False,
    default_value=0,
    message_type=None,
    enum_type=None,
    containing_type=None,
    is_extension=True,
    extension_scope=None,
    serialized_options=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
)


_VOID = _descriptor.Descriptor(
    name="Void",
    full_name="hrpc.Void",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto2",
    extension_ranges=[],
    oneofs=[],
    serialized_start=54,
    serialized_end=60,
)

DESCRIPTOR.message_types_by_name["Void"] = _VOID
DESCRIPTOR.extensions_by_name["service"] = service
DESCRIPTOR.extensions_by_name["method"] = method
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Void = _reflection.GeneratedProtocolMessageType(
    "Void",
    (_message.Message,),
    {
        "DESCRIPTOR": _VOID,
        "__module__": "hrpc_pb2"
        # @@protoc_insertion_point(class_scope:hrpc.Void)
    },
)
_sym_db.RegisterMessage(Void)

google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(
    service
)
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(method)

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['hyperspace_rpc']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'hyperspace-rpc',
    'version': '0.0.1a3',
    'description': 'Raw RPC layer for Hyperspace',
    'long_description': '# hyperspace-rpc\n\n[![Build Status](https://drone.autonomic.zone/api/badges/hyperpy/hyperspace-rpc/status.svg)](https://drone.autonomic.zone/hyperpy/hyperspace-rpc)\n\n## Raw RPC layer for Hyperspace\n\n## Install\n\n```sh\n$ pip install hyperspace-rpc\n```\n\n## Example\n\nSee [hyperpy/hyperspace-client](https://github.com/hyperpy/hyperspace-client).\n',
    'author': 'decentral1se',
    'author_email': 'hi@decentral1.se',
    'maintainer': 'decentral1se',
    'maintainer_email': 'hi@decentral1.se',
    'url': 'https://github.com/hyperpy/hyperspace-rpc',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
